@@ -1,6 +1,7 @@
 from keyring import get_password
 from mongoengine import *
 from cryptomodel.operations import OPERATIONS
+from cryptomodel.order_types import ORDER_TYPES
 from cryptomodel.transaction_types import TRANSACTION_TYPES
 
 
@@ -37,6 +38,7 @@ class user_transaction(Document):
     date = DateField()
     source = StringField()
     currency = StringField()
+    order_type = StringField(choices=ORDER_TYPES.choices())
     type = StringField(choices=TRANSACTION_TYPES.choices())
     source_id = ObjectIdField()
     operation = StringField(choices=OPERATIONS.choices())
